@@ -6,4 +6,4 @@ function(){
 return  new J.adapter.readers.cif.Cif2DataParser().set(this, null, this.debugging);
 });
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
