@@ -1151,4 +1151,4 @@ return this.atoms[iPrev].chainID != this.atoms[i].chainID;
 }, "~N,~N");
 c$.nucleic = " A C G T U ADE THY CYT GUA URI DA DC DG DT DU ";
 });
-;//5.0.1-v7 Sun Nov 02 22:55:28 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
