@@ -1296,4 +1296,4 @@ this.jmolToUniqueID =  Clazz.newIntArray (nAtomsJmol, 0);
 }, "~N");
 c$.MEAS_DIGITS =  Clazz.newIntArray(-1, [530, 531, 532]);
 });
-;//5.0.1-v7 Sun Nov 02 22:55:28 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
