@@ -185,4 +185,4 @@ JU.Logger.info("Molecular dipole for model " + this.asc.atomSetCount + " = " + d
 this.asc.setCurrentModelInfo("dipole", dipole);
 }});
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
