@@ -406,4 +406,4 @@ for (var i = 0; i < this.modelAtomCount; i++) this.setAtomCoordScaled(atoms[i +
 
 }, "~S,~B,~B");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
