@@ -396,4 +396,4 @@ if (charge != 0) name += "<sup>" + Math.abs(charge) + (charge > 0 ? "+" : charge
 }return name;
 }, "JM.Atom");
 });
-;//5.0.1-v7 Sun Nov 02 22:55:28 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
