@@ -186,4 +186,4 @@ c$.$DC_LIST = "xx    yy    zz    xy    xz    yz";
 c$.$FS_LIST = "NOT IMPLEMENTED IN THIS READER";
 c$.$FC_LIST = "xxx   yyy   zzz   yyx   xxy   xxz   zzx   zzy   yyz   xyz";
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
