@@ -62,4 +62,4 @@ this.asc.addBond( new J.adapter.smarter.Bond(atomIndex1, atomIndex2, order));
 }
 }, "~N");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
