@@ -67,4 +67,4 @@ this.asc.atoms[i + this.baseAtomIndex].partialCharge = Float.parseFloat(this.lin
 }
 });
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
