@@ -798,4 +798,4 @@ b1.connect(a1, a2);
 };
 Clazz.declareInterface(J.adapter.readers.xml.CDXMLParser, "CDXReaderI");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
