@@ -559,4 +559,4 @@ this.ms.addModulation(null, key, this.setRigidBodyPhase(key,  Clazz.newDoubleArr
 }, "~S,~N,~N");
 c$.XYZ =  Clazz.newArray(-1, ["x", "y", "z"]);
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
