@@ -1296,4 +1296,4 @@ return this.nSpins;
 }, "J.adapter.smarter.AtomSetCollection,~B");
 /*eoif3*/})();
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
