@@ -2,4 +2,4 @@ Clazz.declarePackage("J.api");
 Clazz.load(["J.api.FontManager"], "J.api.GenericPlatform", null, function(){
 var c$ = Clazz.declareInterface(J.api, "GenericPlatform", J.api.FontManager);
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
