@@ -1,3 +1,3 @@
 Clazz.declarePackage("J.api");
 Clazz.declareInterface(J.api, "JmolScriptEvaluator");
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
