@@ -84,4 +84,4 @@ if (inSide) for (var i = 0; i < n; i++) normals[i].scale(-1);
 return JU.MeshSurface.newMesh(false, vertexes, 0, faces, normals, 0);
 }, "~B");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
