@@ -228,4 +228,4 @@ Clazz.overrideMethod(c$, "plotText",
 function(x, y, z, colix, text, font3d){
 }, "~N,~N,~N,~N,~S,JU.Font");
 });
-;//5.0.1-v7 Sun Nov 02 22:55:28 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
