@@ -361,4 +361,4 @@ for (var top = 0; top < numTopStrandPoints && (top + numTopStrandPoints) < size;
 c$.vAB =  new JU.V3();
 c$.vAC =  new JU.V3();
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
