@@ -8,4 +8,4 @@ function(vwr, files, width, height, fps, fileName){
 return this.errorMsg;
 }, "JV.Viewer,~A,~N,~N,~N,~S");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
