@@ -52,4 +52,4 @@ function(vwr, smilesOptions){
 return  new J.inchi.InchiToSmilesConverter(this).getSmiles(vwr, smilesOptions);
 }, "JV.Viewer,~S");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
