@@ -692,4 +692,4 @@ if (sb.length() == 0) sb.append("Line 1\nLine 2\n");
 }, "J.jvxl.data.VolumeData,JU.SB");
 c$.haveXMLUtil = false;
 });
-;//5.0.1-v7 Tue Nov 04 17:44:44 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
