@@ -198,4 +198,4 @@ System.out.println("CifDensityReader checkSum=" + this.checkSum);
 Clazz.superCall(this, J.jvxl.readers.BCifDensityReader, "closeReader", []);
 });
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
