@@ -96,4 +96,4 @@ this.volumeData.voxelPtToXYZ(x, y, z, this.ptTemp);
 return this.getValueAtPoint(this.ptTemp, false);
 }, "~N,~N,~N");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
