@@ -31,4 +31,4 @@ var m = J.api.Interface.getOption("quantum." + this.type + "Calculation", this.s
 m.calculate(this.volumeData, this.bsMySelected, this.atomData.xyz, this.atomData.atoms, this.params.theProperty, this.params.mep_calcType);
 });
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
