@@ -59,4 +59,4 @@ this.voxelData = null;
 if (this.dataMin > this.params.cutoff) this.params.cutoff = 2 * this.dataMin;
 }, "~B");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
