@@ -202,4 +202,4 @@ function(){
 return (this.isBinary ? this.binarydoc.readFloat() : this.parseFloatStr(this.nextToken()));
 });
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
