@@ -124,4 +124,4 @@ JU.Logger.info("PyMOLMeshReader rmsd=" + rmsd + " mean=" + mean);
 return this.params.sigma * rmsd + mean;
 });
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
