@@ -709,4 +709,4 @@ if (name.indexOf("captureLooping") >= 0) info = (this.vwr.am.animationReplayMode
 return (info == null ? text : text.substring(0, pt) + " (" + info + ")");
 }, "~S,~S");
 });
-;//5.0.1-v7 Tue Jul 22 18:14:29 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
