@@ -647,4 +647,4 @@ c$.nf = java.text.NumberFormat.getInstance();
 J.quantum.NMRNoeMatrix.nf.setMinimumFractionDigits(4);
 J.quantum.NMRNoeMatrix.nf.setMaximumFractionDigits(4);
 }});
-;//5.0.1-v7 Sun Nov 02 22:55:28 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
