@@ -108,4 +108,4 @@ this.shiftC = ((this.periodicity & 0x4) == 0);
 this.shifting = (this.shiftA || this.shiftB || this.shiftC);
 });
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
