@@ -47,4 +47,4 @@ if (this.mar > 0) this.g3d.fillCylinderXYZ(this.colix, this.colix, 2, this.width
  else this.g3d.drawLineXYZ(xA, yA, zA, xB, yB, zB);
 }, "~N,~N,~N,~N,~N,~N");
 });
-;//5.0.1-v7 Sun Nov 02 22:55:28 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
