@@ -55,4 +55,4 @@ this.g3d.fillTriangle3CNBits(this.facePt1, this.colix, p1, this.facePt2, this.co
 }
 }, "JU.BS");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
