@@ -184,4 +184,4 @@ if (this.standardVector) this.g3d.fillCylinderBits(2, this.diameter, this.pTemp3
 }if (this.drawCap) this.g3d.fillConeScreen3f(2, this.headWidthPixels, this.screenArrowHead, this.screenVectorEnd, false);
 }, "JM.Atom,JU.Vibration");
 });
-;//5.0.1-v7 Sun Nov 02 22:55:28 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
