@@ -39,4 +39,4 @@ if (atoms[i] != null) atoms[i].setShapeVisibility(this.vf, bsSelected != null &&
 }
 }, "JU.BS");
 });
-;//5.0.1-v7 Sun Nov 02 22:55:28 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
