@@ -2,4 +2,4 @@ Clazz.declarePackage("J.shapebio");
 Clazz.load(["J.shapebio.BioShapeCollection"], "J.shapebio.Ribbons", null, function(){
 var c$ = Clazz.declareType(J.shapebio, "Ribbons", J.shapebio.BioShapeCollection);
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
