@@ -83,4 +83,4 @@ var rd =  new J.atomdata.RadiusData(data, 0, J.atomdata.RadiusData.EnumType.ABSO
 this.setShapeSizeRD(0, rd, bsAtoms);
 }, "~A,JU.BS");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
