@@ -543,4 +543,4 @@ cp.xVdwClash = ((x / 2));
 }}, "JU.ContactPair,~N,~N,~N,~N");
 c$.rdVDW =  new J.atomdata.RadiusData(null, 1, J.atomdata.RadiusData.EnumType.FACTOR, J.c.VDW.AUTO);
 });
-;//5.0.1-v7 Tue Nov 04 20:37:02 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
