@@ -1287,4 +1287,4 @@ function(mesh){
 return (mesh == null ? null : (mesh).getValidVertices(null));
 }, "J.shape.Mesh");
 });
-;//5.0.1-v7 Tue Nov 04 20:39:04 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
