@@ -224,4 +224,4 @@ this.lcaoReverseColor = lc.lcaoReverseColor;
 Clazz.superCall(this, J.shapesurface.LcaoCartoon, "merge", [shape]);
 }, "J.shape.MeshCollection");
 });
-;//5.0.1-v7 Tue Nov 04 19:16:53 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
