@@ -7,4 +7,4 @@ Clazz.superCall(this, J.shapesurface.Plot3D, "initShape", []);
 this.myType = "plot3d";
 });
 });
-;//5.0.1-v7 Tue Nov 04 19:16:53 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
