@@ -72,4 +72,4 @@ for (var i = 0; i < n; i++) pts[i] = JU.P3.newP(vs[a[i][0]]);
 return pts;
 }, "J.shape.Mesh");
 });
-;//5.0.1-v7 Tue Nov 04 19:16:53 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
