@@ -152,4 +152,4 @@ return JU.Quat.getQuaternionFrameV(vA, vB, vC, false);
 }, "~S");
 c$.alphaOffsets =  Clazz.newByteArray(-1, [0]);
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
