@@ -221,4 +221,4 @@ for (var j = b.length; --j >= 0; ) if ((h = b[j].getOtherAtom(a)).getElementNumb
 }, "JU.BS,JM.Atom,~B");
 c$.interestingAminoAtomIDs =  Clazz.newByteArray(-1, [2, -5, 1, 3, -65]);
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
