@@ -2,4 +2,4 @@ Clazz.declarePackage("JM");
 Clazz.load(["JM.ProteinStructure"], "JM.Annotation", null, function(){
 var c$ = Clazz.declareType(JM, "Annotation", JM.ProteinStructure);
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
