@@ -657,4 +657,4 @@ function(s, atomName, aaRet){
 return this.getBioExt().getAminoAcidValenceAndCharge(s, atomName, aaRet);
 }, "~S,~S,~A");
 });
-;//5.0.1-v7 Sun Nov 02 22:55:28 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
