@@ -338,4 +338,4 @@ c$.standardGroupList = null;
 c$.group3Names =  new Array(128);
 c$.specialAtomNames = null;
 });
-;//5.0.1-v7 Sun Nov 02 22:55:28 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
