@@ -77,4 +77,4 @@ if (this.hCount < 0) this.hCount = this.atom.getCovalentHydrogenCount();
 return this.hCount;
 });
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
