@@ -8,4 +8,4 @@ this.setupPS(apolymer, J.c.STR.TURN, monomerIndex, monomerCount);
 this.subtype = J.c.STR.TURN;
 }, "JM.AlphaPolymer,~N,~N");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
