@@ -36,4 +36,4 @@ var angle = this.align1.angle(this.align2);
 return (angle < 0.0);
 }, "JU.T3,JU.T3,JU.T3");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
