@@ -930,4 +930,4 @@ JS.SmilesParser.extractFlags(pattern, ret);
 return ret[0];
 }, "~S");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
