@@ -34,4 +34,4 @@ function(vwr, sym, name, type){
 return this.createSpecialGroup(null, sym, JS.Symmetry.getSpecialSettingInfo(vwr, name, type), type);
 }, "JV.Viewer,JS.Symmetry,~S,~N");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
