@@ -1467,4 +1467,4 @@ c$.wyckoffFinder = null;
 c$.clegInstance = null;
 c$.groupFactory = null;
 });
-;//5.0.1-v7 Sun Nov 02 23:04:34 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
