@@ -23,4 +23,4 @@ this.vNorm4 =  new JU.V3();
 this.bsTemp =  new JU.BS();
 });
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
