@@ -1,3 +1,3 @@
 Clazz.declarePackage("JSV.api");
 Clazz.declareInterface(JSV.api, "SourceReader");
-;//5.0.1-v7 Tue Jul 22 18:14:29 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
