@@ -1,3 +1,3 @@
 Clazz.declarePackage("JSV.api.js");
 Clazz.declareInterface(JSV.api.js, "JSVAppletObject", javajs.api.js.JSAppletObject);
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
