@@ -338,4 +338,4 @@ Clazz.defineEnumConstant(c$, "NA", 9, []);
 c$.c =  new JSV.common.IntegralComparator();
 c$.$HEADER =  Clazz.newArray(-1, ["peak", "start/ppm", "end/ppm", "value"]);
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
