@@ -647,4 +647,4 @@ c$.nmrdbServerH1New = "https://nmr-prediction.service.zakodium.com/v1/predict/pr
 c$.nmrdbServerC13New = "https://nmr-prediction.service.zakodium.com/v1/predict/carbon?POST?{\"molfile\":\"$MOLFILE\",\"includeJDX\":true}";
 c$.stringCount = 0;
 });
-;//5.0.1-v7 Sun Nov 02 22:59:42 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
