@@ -1724,4 +1724,4 @@ c$.isJS = false;
 c$.isSwingJS = false;
 c$.jsmolObject = null;
 });
-;//5.0.1-v7 Sun Nov 02 22:57:33 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
