@@ -148,4 +148,4 @@ function(r, g, b, a){
 return this.g2d.getColor4(r, g, b, a);
 }, "~N,~N,~N,~N");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
