@@ -47,4 +47,4 @@ function(a, b, x){
 return a * Math.exp(-b * x * x);
 }, "~N,~N,~N");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
