@@ -757,4 +757,4 @@ System.out.println("done");
 }, "~A");
 c$.VAR_LIST_TABLE =  Clazz.newArray(-1, ["PEAKTABLE   XYDATA      XYPOINTS", " (XY..XY)    (X++(Y..Y)) (XY..XY)    "]);
 });
-;//5.0.1-v7 Sun Nov 02 22:57:33 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
