@@ -73,4 +73,4 @@ this.spectraTreeModel.removeNodeFromParent(toDelete.get(i));
 }
 }, "JU.Lst");
 });
-;//5.0.1-v7 Sun Nov 02 22:57:33 CST 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
