@@ -87,4 +87,4 @@ c$.vertexVectors = null;
 c$.inverseNormixes = null;
 c$.neighborVertexesArrays = null;
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
