@@ -105,4 +105,4 @@ this.fScrPt.z += this.zOffset;
 this.matrixTransform.rotTrans2(ptXYZ, this.fScrPt);
 }}, "JU.T3");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
