@@ -452,7 +452,7 @@ return f * JU.BC.fracIEEE[i + 140];
 }, "~N,~N");
 c$.fracIEEE = null;
 })();
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
 Clazz_declarePackage("JU");
 Clazz_load(["javajs.api.GenericBinaryDocument", "JU.BC"], "JU.BinaryDocument", ["java.io.DataInputStream"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -678,7 +678,7 @@ function(b){
 this.isBigEndian = b;
 }, "~B");
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
 })(Clazz
 ,Clazz.getClassName
 ,Clazz.newLongArray
