@@ -63,7 +63,7 @@ var $t$;
 //var c$;
 Clazz_declarePackage("J.console");
 Clazz_declareInterface(J.console, "GenericTextArea");
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
 Clazz_declarePackage("J.console");
 Clazz_load(["J.api.JmolAppConsoleInterface", "$.JmolCallbackListener", "java.util.Hashtable"], "J.console.GenericConsole", ["JU.PT", "J.c.CBK", "J.i18n.GT", "JS.T", "JV.Viewer"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -472,7 +472,7 @@ return sout;
 }, "~S");
 c$.labels = null;
 });
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
 Clazz_declarePackage("J.consolejs");
 Clazz_load(["J.console.GenericConsole"], "J.consolejs.AppletConsole", null, function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -837,7 +837,7 @@ return s;
 }
 ;
 }}});
-;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
+;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
 })(Clazz
 ,Clazz.getClassName
 ,Clazz.newLongArray
