@@ -3,8 +3,8 @@ function(){var h=u(function(){this.undoWorking=!1;this.temp4=this.temp3=this.tem
 a},"JV.Viewer");m(h,"getStateScript",function(a,b,d){var c=null==a||a.equalsIgnoreCase("all"),e=new JU.SB,f=c?(new JU.SB).append("function _setState() {\n"):null;c&&(e.append("# Jmol state version "+JV.Viewer.getJmolVersion()+";\n"),this.vwr.isApplet&&(this.app(e,"# fullName = "+JU.PT.esc(this.vwr.fullName)),this.app(e,"# documentBase = "+JU.PT.esc(JV.Viewer.appletDocumentBase)),this.app(e,"# codeBase = "+JU.PT.esc(JV.Viewer.appletCodeBase)),e.append("\n")));var g=this.vwr.g;(c||a.equalsIgnoreCase("windowState"))&&
 e.append(this.getWindowState(f,b,d));(c||a.equalsIgnoreCase("fileState"))&&e.append(this.getFileState(f));(c||a.equalsIgnoreCase("definedState"))&&e.append(this.getDefinedState(f,!0));(c||a.equalsIgnoreCase("variableState"))&&e.append(this.getParameterState(g,f));(c||a.equalsIgnoreCase("dataState"))&&e.append(this.getDataState(f));(c||a.equalsIgnoreCase("modelState"))&&e.append(this.getModelState(f,!0,this.vwr.getBooleanProperty("saveProteinStructureState")));(c||a.equalsIgnoreCase("colorState"))&&
 e.append(this.getColorState(this.vwr.cm,f));(c||a.equalsIgnoreCase("frameState"))&&e.append(this.getAnimState(this.vwr.am,f));(c||a.equalsIgnoreCase("perspectiveState"))&&e.append(this.getViewState(this.vwr.tm,f));(c||a.equalsIgnoreCase("selectionState"))&&e.append(this.getSelectionState(this.vwr.slm,f));null!=f&&(this.app(f,"set refreshing true"),this.app(f,"set antialiasDisplay "+g.antialiasDisplay),this.app(f,"set antialiasTranslucent "+g.antialiasTranslucent),this.app(f,"set antialiasImages "+
-g.antialiasImages),this.vwr.tm.spinOn&&this.app(f,"spin on"),f.append("}\n\n_setState;\n"));c&&e.appendSB(f);return e.toString()},"~S,~N,~N");k(h,"getDataState",function(a){var b=new JU.SB,d=!1,c=this.getAtomicPropertyState(-1,null);0<c.length&&(d=!0,b.append(c));null!=this.vwr.userVdws&&(c=this.vwr.getDefaultVdwNameOrData(0,J.c.VDW.USER,this.vwr.bsUserVdws),0<c.length&&(d=!0,b.append(c)));null!=this.vwr.nmrCalculation&&(d=(new Boolean(d|this.vwr.nmrCalculation.getState(b))).valueOf());null!=this.vwr.dm&&
-(d=(new Boolean(d|this.vwr.dm.getDataState(this,b))).valueOf());if(!d)return"";d="";null!=a&&(a.append("  _setDataState;\n"),d="function _setDataState() {\n",b.append("}\n\n"));return d+b.toString()},"JU.SB");k(h,"getDefinedState",function(a,b){var d=this.vwr.ms,c=d.stateScripts.size();if(0==c)return"";for(var e=!1,f=new JU.SB,g,l=0;l<c;l++){var p=d.stateScripts.get(l);if(p.inDefinedStateBlock&&0<(g=p.toString()).length)this.app(f,g),e=!0}if(!e)return"";g="";b&&null!=a&&(a.append("  _setDefinedState;\n"),
+g.antialiasImages),this.vwr.tm.spinOn&&!this.vwr.tm.vectorSpinOnly&&this.app(f,"spin on"),f.append("}\n\n_setState;\n"));c&&e.appendSB(f);return e.toString()},"~S,~N,~N");k(h,"getDataState",function(a){var b=new JU.SB,d=!1,c=this.getAtomicPropertyState(-1,null);0<c.length&&(d=!0,b.append(c));null!=this.vwr.userVdws&&(c=this.vwr.getDefaultVdwNameOrData(0,J.c.VDW.USER,this.vwr.bsUserVdws),0<c.length&&(d=!0,b.append(c)));null!=this.vwr.nmrCalculation&&(d=(new Boolean(d|this.vwr.nmrCalculation.getState(b))).valueOf());
+null!=this.vwr.dm&&(d=(new Boolean(d|this.vwr.dm.getDataState(this,b))).valueOf());if(!d)return"";d="";null!=a&&(a.append("  _setDataState;\n"),d="function _setDataState() {\n",b.append("}\n\n"));return d+b.toString()},"JU.SB");k(h,"getDefinedState",function(a,b){var d=this.vwr.ms,c=d.stateScripts.size();if(0==c)return"";for(var e=!1,f=new JU.SB,g,l=0;l<c;l++){var p=d.stateScripts.get(l);if(p.inDefinedStateBlock&&0<(g=p.toString()).length)this.app(f,g),e=!0}if(!e)return"";g="";b&&null!=a&&(a.append("  _setDefinedState;\n"),
 g="function _setDefinedState() {\n\n");null!=a&&f.append("\n}\n\n");return g+f.toString()},"JU.SB,~B");m(h,"getModelState",function(a,b,d){var c=new JU.SB;b&&null!=a&&(a.append("  _setModelState;\n"),c.append("function _setModelState() {\n"));var e,f=this.vwr.ms,g=f.bo,l=f.am,p=f.mc;if(b){for(var h=f.stateScripts.size(),j=0;j<h;j++){var k=f.stateScripts.get(j);!k.inDefinedStateBlock&&0<(e=k.toString()).length&&this.app(c,e)}e=new JU.SB;h=!1;if(null!=f.unitCells){k=!1;for(j=0;j<p;j++){var m=f.getUnitCell(j);
 null!=m&&(e.setLength(0),m.getState(f,j,e)&&(h=!0,c.append("  frame ").append(f.getModelNumberDotted(j)).appendSB(e).append(";\n")),k=(new Boolean(k|0<=this.vwr.ms.getLastVibrationVector(j,1275072532))).valueOf())}h&&this.vwr.shm.loadShape(33);this.getShapeStatePriv(c,b,33);if(k){h=new java.util.Hashtable;for(j=p;0<=--j;)if(0<=(k=this.vwr.ms.getLastVibrationVector(j,1275072532)))for(m=l[j].firstAtomIndex;m<=k;m++){var n=f.getModulation(m);null!=n&&JU.BSUtil.setMapBitSet(h,m,m,n.getState())}c.append(this.getCommands(h,
 null,"select"))}}e.setLength(0);for(j=0;j<f.bondCount;j++)if(null!=g[j]&&!l[g[j].atom1.mi].isModelKit&&(g[j].isHydrogen()||0!=(g[j].order&131072)))h=g[j],k=h.atom1.i,h.atom1.group.isAdded(k)&&(k=-1-k),e.appendI(k).appendC("\t").appendI(h.atom2.i).appendC("\t").appendI(h.order&131071).appendC("\t").appendD(h.mad/1E3).appendC("\t").appendD(h.getEnergy()).appendC("\t").append(JU.Edge.getBondOrderNameFromOrder(h.order)).append(";\n");0<e.length()&&c.append('data "connect_atoms"\n').appendSB(e).append('end "connect_atoms";\n');
@@ -32,12 +32,12 @@ return d.toString()},"JV.SelectionManager,JU.SB");k(h,"getViewState",function(a,
 this.app(d,"set cameraDepth "+a.cameraDepth);var e=1==a.mode;e&&this.app(d,"set navigationMode true");this.app(d,this.vwr.ms.getBoundBoxCommand(!1));this.app(d,"center "+JU.Escape.eP(a.fixedRotationCenter));d.append(this.vwr.getOrientation(1073742034,null,null,null).toString());this.app(d,c);!e&&!a.zoomEnabled&&this.app(d,"zoom off");d.append("  slab ").appendI(a.slabPercentSetting).append(";depth ").appendI(a.depthPercentSetting).append(a.slabEnabled&&!e?";slab on":"").append(";\n");d.append("  set slabRange ").appendF(a.slabRange).append(";\n");
 null!=a.slabPlane&&d.append("  slab plane ").append(JU.Escape.eP4(a.slabPlane)).append(";\n");null!=a.depthPlane&&d.append("  depth plane ").append(JU.Escape.eP4(a.depthPlane)).append(";\n");this.getZshadeState(d,a,!1);d.append(this.getSpinState(!0)).append("\n");this.vwr.ms.modelSetHasVibrationVectors()&&a.vibrationOn&&this.app(d,"set vibrationPeriod "+a.vibrationPeriod+";vibration on");c=null!=a.depthPlane||null!=a.slabPlane;e&&d.append(a.getNavigationState());!a.slabEnabled&&c&&d.append("  slab off;\n");
 null!=b&&d.append("}\n\n");return d.toString()},"JV.TransformManager,JU.SB");k(h,"getZshadeState",function(a,b,d){d&&(this.app(a,"set zDepth "+b.zDepthPercentSetting),this.app(a,"set zSlab "+b.zSlabPercentSetting),b.zShadeEnabled||this.app(a,"set zShade false"));b.zShadeEnabled&&this.app(a,"set zShade true");try{null!=b.zSlabPoint&&this.app(a,"set zSlab "+JU.Escape.eP(b.zSlabPoint))}catch(c){if(!w(c,Exception))throw c;}},"JU.SB,JV.TransformManager,~B");m(h,"getSpinState",function(){var a=this.vwr.tm,
-b="  set spinX "+n(a.spinX)+"; set spinY "+n(a.spinY)+"; set spinZ "+n(a.spinZ)+"; set spinFps "+n(a.spinFps)+";";Float.isNaN(a.navFps)||(b+="  set navX "+n(a.navX)+"; set navY "+n(a.navY)+"; set navZ "+n(a.navZ)+"; set navFps "+n(a.navFps)+";");a.navOn&&(b+=" navigation on;");if(!a.spinOn)return b;var d=a.isSpinSelected?"\n  select "+JU.Escape.eBS(this.vwr.bsA())+";\n  rotateSelected":"\n ";if(a.isSpinInternal){var c=JU.P3.newP(a.internalRotationCenter);c.sub(a.rotationAxis);b+=d+" spin "+a.rotationRate+
-" "+JU.Escape.eP(a.internalRotationCenter)+" "+JU.Escape.eP(c)}else b=a.isSpinFixed?b+(d+" spin axisangle "+JU.Escape.eP(a.rotationAxis)+" "+a.rotationRate):b+" spin on";return b+";"},"~B");m(h,"getCommands",function(a,b,d){var c=new JU.SB;a=this.getCommands2(a,c,null,d);null!=b&&this.getCommands2(b,c,a,"select");return c.toString()},"java.util.Map,java.util.Map,~S");k(h,"getCommands2",function(a,b,d,c){if(null==a)return"";var e;for(a=a.entrySet().iterator();a.hasNext()&&((e=a.next())||1);){var f=
-e.getKey(),g=JU.Escape.eBS(e.getValue());5>g.length||(g=c+" "+g,g.equals(d)||this.app(b,g),d=g,0!=f.indexOf("-")&&this.app(b,f))}return d},"java.util.Map,JU.SB,~S,~S");k(h,"app",function(a,b){0!=b.length&&a.append("  ").append(b).append(";\n")},"JU.SB,~S");k(h,"addBs",function(a,b,d){null==d||0==d.length()||this.app(a,b+JU.Escape.eBS(d))},"JU.SB,~S,JU.BS");k(h,"getFontState",function(a,b){var d=JV.StateManager.getObjectIdFromName(a.equalsIgnoreCase("axes")?"axis":a);if(0>d)return"";var c=this.vwr.getObjectMad10(d),
-d=(new JU.SB).append("\n");this.app(d,a+(0==c?" off":1==c?" on":-1==c?" dotted":20>c?" "+c:" "+c/2E4));if(3>d.length())return"";c=J.shape.Shape.getFontCommand(a,b);0<c.length&&(c="  "+c+";\n");return d+c},"~S,JU.Font");k(h,"appendTickInfo",function(a,b,d){b.append("  ");b.append(a);JV.StateCreator.addTickInfo(b,d,!1);b.append(";\n")},"~S,JU.SB,JM.TickInfo");h.addTickInfo=k(h,"addTickInfo",function(a,b,d){a.append(" ticks ").appendC(b.type).append(" ").append(JU.Escape.eP(b.ticks));var c=null!=b.scale&&
-Float.isNaN(b.scale.x);c&&a.append(" UNITCELL");null!=b.tickLabelFormats&&a.append(" format ").append(JU.Escape.eAS(b.tickLabelFormats,!1));!c&&null!=b.scale&&a.append(" scale ").append(JU.Escape.eP(b.scale));d&&(!Float.isNaN(b.first)&&0!=b.first)&&a.append(" first ").appendF(b.first);null!=b.reference&&a.append(" point ").append(JU.Escape.eP(b.reference))},"JU.SB,JM.TickInfo,~B");k(h,"getMeasurementState",function(a){var b=a.measurements,d=a.measurementCount,c=a.font3d,e=a.defaultTickInfo,f=new JU.SB;
-this.app(f,"measures delete");for(var g=0;g<d;g++){var l=b.get(g),h=null!=l.property;if(!h||!Float.isNaN(l.value)){var k=l.count,j=(new JU.SB).append("measure");null!=l.thisID&&j.append(" ID ").append(JU.PT.esc(l.thisID));0!=l.mad&&j.append(" radius ").appendF(null==l.thisID||0<l.mad?l.mad/2E3:0);0!=l.colix&&j.append(" color ").append(JU.Escape.escapeColor(JU.C.getArgb(l.colix)));null!=l.text&&(null!=l.text.font&&j.append(" font ").append(l.text.font.getInfo()),0!=l.text.align&&j.append(" align ").append(JV.JC.getHorizAlignmentName(l.text.align)),
+b="  set spinX "+n(a.spinX)+"; set spinY "+n(a.spinY)+"; set spinZ "+n(a.spinZ)+"; set spinFps "+n(a.spinFps)+";";Float.isNaN(a.navFps)||(b+="  set navX "+n(a.navX)+"; set navY "+n(a.navY)+"; set navZ "+n(a.navZ)+"; set navFps "+n(a.navFps)+";");a.navOn&&(b+=" navigation on;");if(!a.spinOn||a.vectorSpinOnly)return b;var d=a.isSpinSelected?"\n  select "+JU.Escape.eBS(this.vwr.bsA())+";\n  rotateSelected":"\n ";if(a.isSpinInternal){var c=JU.P3.newP(a.internalRotationCenter);c.sub(a.rotationAxis);b+=
+d+" spin "+a.rotationRate+" "+JU.Escape.eP(a.internalRotationCenter)+" "+JU.Escape.eP(c)}else b=a.isSpinFixed?b+(d+" spin axisangle "+JU.Escape.eP(a.rotationAxis)+" "+a.rotationRate):b+" spin on";return b+";"},"~B");m(h,"getCommands",function(a,b,d){var c=new JU.SB;a=this.getCommands2(a,c,null,d);null!=b&&this.getCommands2(b,c,a,"select");return c.toString()},"java.util.Map,java.util.Map,~S");k(h,"getCommands2",function(a,b,d,c){if(null==a)return"";var e;for(a=a.entrySet().iterator();a.hasNext()&&
+((e=a.next())||1);){var f=e.getKey(),g=JU.Escape.eBS(e.getValue());5>g.length||(g=c+" "+g,g.equals(d)||this.app(b,g),d=g,0!=f.indexOf("-")&&this.app(b,f))}return d},"java.util.Map,JU.SB,~S,~S");k(h,"app",function(a,b){0!=b.length&&a.append("  ").append(b).append(";\n")},"JU.SB,~S");k(h,"addBs",function(a,b,d){null==d||0==d.length()||this.app(a,b+JU.Escape.eBS(d))},"JU.SB,~S,JU.BS");k(h,"getFontState",function(a,b){var d=JV.StateManager.getObjectIdFromName(a.equalsIgnoreCase("axes")?"axis":a);if(0>
+d)return"";var c=this.vwr.getObjectMad10(d),d=(new JU.SB).append("\n");this.app(d,a+(0==c?" off":1==c?" on":-1==c?" dotted":20>c?" "+c:" "+c/2E4));if(3>d.length())return"";c=J.shape.Shape.getFontCommand(a,b);0<c.length&&(c="  "+c+";\n");return d+c},"~S,JU.Font");k(h,"appendTickInfo",function(a,b,d){b.append("  ");b.append(a);JV.StateCreator.addTickInfo(b,d,!1);b.append(";\n")},"~S,JU.SB,JM.TickInfo");h.addTickInfo=k(h,"addTickInfo",function(a,b,d){a.append(" ticks ").appendC(b.type).append(" ").append(JU.Escape.eP(b.ticks));
+var c=null!=b.scale&&Float.isNaN(b.scale.x);c&&a.append(" UNITCELL");null!=b.tickLabelFormats&&a.append(" format ").append(JU.Escape.eAS(b.tickLabelFormats,!1));!c&&null!=b.scale&&a.append(" scale ").append(JU.Escape.eP(b.scale));d&&(!Float.isNaN(b.first)&&0!=b.first)&&a.append(" first ").appendF(b.first);null!=b.reference&&a.append(" point ").append(JU.Escape.eP(b.reference))},"JU.SB,JM.TickInfo,~B");k(h,"getMeasurementState",function(a){var b=a.measurements,d=a.measurementCount,c=a.font3d,e=a.defaultTickInfo,
+f=new JU.SB;this.app(f,"measures delete");for(var g=0;g<d;g++){var l=b.get(g),h=null!=l.property;if(!h||!Float.isNaN(l.value)){var k=l.count,j=(new JU.SB).append("measure");null!=l.thisID&&j.append(" ID ").append(JU.PT.esc(l.thisID));0!=l.mad&&j.append(" radius ").appendF(null==l.thisID||0<l.mad?l.mad/2E3:0);0!=l.colix&&j.append(" color ").append(JU.Escape.escapeColor(JU.C.getArgb(l.colix)));null!=l.text&&(null!=l.text.font&&j.append(" font ").append(l.text.font.getInfo()),0!=l.text.align&&j.append(" align ").append(JV.JC.getHorizAlignmentName(l.text.align)),
 null!=l.text.pymolOffset&&j.append(" offset ").append(JU.Escape.eAF(l.text.pymolOffset)));var m=l.tickInfo;null!=m&&JV.StateCreator.addTickInfo(j,m,!0);for(m=1;m<=k;m++)j.append(" ").append(l.getLabel(m,!0,!0));h?j.append(" "+l.property+" value "+(Double.isNaN(l.value)?0:l.value)).append(" "+JU.PT.esc(l.getString())):2==k&&(l=l.getDistanceFormatForState(),null!=l&&j.append(" ").append(JU.PT.esc(l)));h||j.append("; # "+a.getInfoAsString(g));this.app(f,j.toString())}}this.app(f,J.shape.Shape.getFontCommand("measures",
 c));c=0;h=new java.util.Hashtable;j=JU.BS.newN(d);for(g=0;g<d;g++)l=b.get(g),l.isHidden&&(c++,j.set(g)),null!=a.bsColixSet&&a.bsColixSet.get(g)&&JU.BSUtil.setMapBitSet(h,g,g,J.shape.Shape.getColorCommandUnk("measure",l.colix,a.translucentAllowed));if(0<c)if(c==d)this.app(f,"measures off; # lines and numbers off");else for(g=0;g<d;g++)j.get(g)&&JU.BSUtil.setMapBitSet(h,g,g,"measure off");null!=e&&(f.append(" measure "),JV.StateCreator.addTickInfo(f,e,!0),f.append(";\n"));0<=a.mad&&f.append(" set measurements ").appendF(a.mad/
 2E3).append(";\n");l=this.getCommands(h,null,"select measures");null!=l&&0!=l.length&&(f.append(l),this.app(f,"select measures ({null})"));return f.toString()},"J.shape.Measures");k(h,"getShapeStatePriv",function(a,b,d){var c=this.vwr.shm.shapes;if(null!=c){var e;2147483647==d?(d=0,e=37):e=d+1;for(;d<e;++d){var f=c[d];if(null!=f&&(b||9<=d&&16>d))f=this.getShapeState(f),null!=f&&1<f.length&&a.append(f)}a.append("  select *;\n")}},"JU.SB,~B,~N");k(h,"getBondState",function(a){var b=a.bsOrderSet,d=a.reportAll;
