@@ -16,18 +16,18 @@ this.entryEOF=!0});k(b,"available",function(){this.ensureOpen();return this.entr
 m=this.$in.read(a,c,m);if(-1==m)throw new java.util.zip.ZipException("unexpected EOF");this.crc.update(a,c,m);this.remaining-=m;if(0==this.remaining&&this.entry.crc!=this.crc.getValue())throw new java.util.zip.ZipException("invalid entry CRC (expected 0x"+Long.toHexString(this.entry.crc)+" but got 0x"+Long.toHexString(this.crc.getValue())+")");return m;default:throw new java.util.zip.ZipException("invalid compression method");}},"~A,~N,~N");k(b,"skip",function(a){if(0>a)throw new IllegalArgumentException("negative skip length");
 this.ensureOpen();a=Math.min(a,2147483647);for(var c=0;c<a;){var m=a-c;m>this.tmpbuf.length&&(m=this.tmpbuf.length);m=this.read(this.tmpbuf,0,m);if(-1==m){this.entryEOF=!0;break}c+=m}return c},"~N");d(b,"close",function(){this.$closed||(P(this,java.util.zip.ZipInputStream,"close",[]),this.$closed=!0)});d(b,"readLOC",function(){try{this.readFully(this.tmpbuf,0,30)}catch(a){if(t(a,"java.io.EOFException"))return null;throw a;}if(67324752!=java.util.zip.ZipInputStream.get32(this.tmpbuf,0))return null;
 this.flag=java.util.zip.ZipInputStream.get16(this.tmpbuf,6);var c=java.util.zip.ZipInputStream.get16(this.tmpbuf,26),m=this.$b.length;if(c>m){do m*=2;while(c>m);this.$b=x(m,0)}this.readFully(this.$b,0,c);m=this.createZipEntry(0!=(this.flag&2048)?this.toStringUTF8(this.$b,c):this.toStringb2(this.$b,c));if(1==(this.flag&1))throw new java.util.zip.ZipException("encrypted ZIP entry not supported");m.method=java.util.zip.ZipInputStream.get16(this.tmpbuf,8);m.time=java.util.zip.ZipInputStream.get32(this.tmpbuf,
-10);if(8==(this.flag&8)){if(8!=m.method)throw new java.util.zip.ZipException("only DEFLATED entries can have EXT descriptor");}else m.crc=java.util.zip.ZipInputStream.get32(this.tmpbuf,14),m.csize=java.util.zip.ZipInputStream.get32(this.tmpbuf,18),m.size=java.util.zip.ZipInputStream.get32(this.tmpbuf,22);c=java.util.zip.ZipInputStream.get16(this.tmpbuf,28);if(0<c){var b=x(c,0);this.readFully(b,0,c);m.setExtra(b);if(4294967295==m.csize||4294967295==m.size)for(var g=0;g+4<c;){var h=java.util.zip.ZipInputStream.get16(b,
-g+2);if(1==java.util.zip.ZipInputStream.get16(b,g)){g+=4;if(16>h||g+h>c)break;m.size=java.util.zip.ZipInputStream.get64(b,g);m.csize=java.util.zip.ZipInputStream.get64(b,g+8);break}g+=h+4}}return m});d(b,"toStringUTF8",function(a,c){try{return String.instantialize(a,0,c,this.zc)}catch(b){if(t(b,"java.io.UnsupportedEncodingException"))return this.toStringb2(a,c);throw b;}},"~A,~N");d(b,"toStringb2",function(a,c){return String.instantialize(a,0,c)},"~A,~N");d(b,"createZipEntry",function(a){return new java.util.zip.ZipEntry(a)},
-"~S");d(b,"readEnd",function(a){var c=this.inf.getAvailIn();0<c&&(this.$in.unread(this.buf,this.len-c,c),this.eof=!1);8==(this.flag&8)&&(4294967295<this.inf.getTotalOut()||4294967295<this.inf.getTotalIn()?(this.readFully(this.tmpbuf,0,24),c=java.util.zip.ZipInputStream.get32(this.tmpbuf,0),134695760!=c?(a.crc=c,a.csize=java.util.zip.ZipInputStream.get64(this.tmpbuf,4),a.size=java.util.zip.ZipInputStream.get64(this.tmpbuf,12),this.$in.unread(this.tmpbuf,19,4)):(a.crc=java.util.zip.ZipInputStream.get32(this.tmpbuf,
-4),a.csize=java.util.zip.ZipInputStream.get64(this.tmpbuf,8),a.size=java.util.zip.ZipInputStream.get64(this.tmpbuf,16))):(this.readFully(this.tmpbuf,0,16),c=java.util.zip.ZipInputStream.get32(this.tmpbuf,0),134695760!=c?(a.crc=c,a.csize=java.util.zip.ZipInputStream.get32(this.tmpbuf,4),a.size=java.util.zip.ZipInputStream.get32(this.tmpbuf,8),this.$in.unread(this.tmpbuf,11,4)):(a.crc=java.util.zip.ZipInputStream.get32(this.tmpbuf,4),a.csize=java.util.zip.ZipInputStream.get32(this.tmpbuf,8),a.size=
-java.util.zip.ZipInputStream.get32(this.tmpbuf,12))));if(a.size!=this.inf.getTotalOut())throw new java.util.zip.ZipException("invalid entry size (expected "+a.size+" but got "+this.inf.getTotalOut()+" bytes)");if(a.csize!=this.inf.getTotalIn())throw new java.util.zip.ZipException("invalid entry compressed size (expected "+a.csize+" but got "+this.inf.getTotalIn()+" bytes)");if(a.crc!=this.crc.getValue())throw new java.util.zip.ZipException("invalid entry CRC (expected 0x"+Long.toHexString(a.crc)+
-" but got 0x"+Long.toHexString(this.crc.getValue())+")");},"java.util.zip.ZipEntry");d(b,"readFully",function(a,c,b){for(;0<b;){var e=this.$in.read(a,c,b);if(-1==e)throw new java.io.EOFException;c+=e;b-=e}},"~A,~N,~N");b.get16=d(b,"get16",function(a,c){return a[c]&255|(a[c+1]&255)<<8},"~A,~N");b.get32=d(b,"get32",function(a,c){return(java.util.zip.ZipInputStream.get16(a,c)|java.util.zip.ZipInputStream.get16(a,c+2)<<16)&4294967295},"~A,~N");b.get64=d(b,"get64",function(a,c){return java.util.zip.ZipInputStream.get32(a,
-c)|java.util.zip.ZipInputStream.get32(a,c+4)<<32},"~A,~N")});z("java.util.zip");y(["com.jcraft.jzlib.CRC32"],"java.util.zip.CRC32",null,function(){F(java.util.zip,"CRC32",com.jcraft.jzlib.CRC32)});z("java.util.zip");y(["com.jcraft.jzlib.InflaterInputStream"],"java.util.zip.InflaterInputStream",null,function(){var b=A(function(){this.inf=null;B(this,arguments)},java.util.zip,"InflaterInputStream",com.jcraft.jzlib.InflaterInputStream);D(b,function(a,c,b){K(this,java.util.zip.InflaterInputStream,[a,
-c,b,!0]);this.inf=c},"java.io.InputStream,java.util.zip.Inflater,~N")});z("java.util.zip");y(["java.util.zip.InflaterInputStream","$.CRC32"],"java.util.zip.GZIPInputStream",["java.util.zip.CheckedInputStream","$.Inflater"],function(){var b=A(function(){this.crc=null;this.$closed=this.eos=!1;this.tmpbuf=null;B(this,arguments)},java.util.zip,"GZIPInputStream",java.util.zip.InflaterInputStream);L(b,function(){this.crc=new java.util.zip.CRC32;this.tmpbuf=x(128,0)});D(b,function(a,c){K(this,java.util.zip.GZIPInputStream,
-[a,(new java.util.zip.Inflater).init(0,!0),c]);this.readHeader(a)},"java.io.InputStream,~N");d(b,"ensureOpen",function(){if(this.$closed)throw new java.io.IOException("Stream closed");});d(b,"read",function(a,c,b){this.ensureOpen();if(this.eos)return-1;var e=this.readInf(a,c,b);if(-1==e)if(this.readTrailer())this.eos=!0;else return this.read(a,c,b);else this.crc.update(a,c,e);return e},"~A,~N,~N");d(b,"close",function(){this.$closed||(P(this,java.util.zip.GZIPInputStream,"close",[]),this.$closed=
-this.eos=!0)});d(b,"readHeader",function(a){a=(new java.util.zip.CheckedInputStream(a)).set(this.crc);this.crc.reset();if(35615!=this.readUShort(a))throw new java.util.zip.ZipException("Not in GZIP format");if(8!=this.readUByte(a))throw new java.util.zip.ZipException("Unsupported compression method");var c=this.readUByte(a);this.skipBytes(a,6);var b=10;if(4==(c&4)){var e=this.readUShort(a);this.skipBytes(a,e);b+=e+2}if(8==(c&8)){do b++;while(0!=this.readUByte(a))}if(16==(c&16)){do b++;while(0!=this.readUByte(a))
-}if(2==(c&2)){c=this.crc.getValue()&65535;if(this.readUShort(a)!=c)throw new java.util.zip.ZipException("Corrupt GZIP header");b+=2}this.crc.reset();return b},"java.io.InputStream");d(b,"readTrailer",function(){return!0});d(b,"readUShort",function(a){var c=this.readUByte(a);return this.readUByte(a)<<8|c},"java.io.InputStream");d(b,"readUByte",function(a){a=a.readByteAsInt();if(-1==a)throw new java.io.EOFException;if(-1>a||255<a)throw new java.io.IOException(this.$in.getClass().getName()+".read() returned value out of range -1..255: "+
-a);return a},"java.io.InputStream");d(b,"skipBytes",function(a,c){for(;0<c;){var b=a.read(this.tmpbuf,0,c<this.tmpbuf.length?c:this.tmpbuf.length);if(-1==b)throw new java.io.EOFException;c-=b}},"java.io.InputStream,~N")});z("javajs.api");y(["java.util.zip.ZipInputStream","javajs.api.ZInputStream"],"javajs.api.GenericZipInputStream",null,function(){F(javajs.api,"GenericZipInputStream",java.util.zip.ZipInputStream,javajs.api.ZInputStream)});z("JU");y(["javajs.api.GenericZipTools"],"JU.ZipTools","java.io.BufferedInputStream java.util.zip.CRC32 $.GZIPInputStream $.ZipEntry javajs.api.GenericZipInputStream $.Interface JU.BArray $.Lst $.Rdr $.SB".split(" "),
+10);if(8!=(this.flag&8)||8!=m.getMethod())m.setCrc(java.util.zip.ZipInputStream.get32(this.tmpbuf,14)),m.setCompressedSize(java.util.zip.ZipInputStream.get32(this.tmpbuf,18)),m.setSize(java.util.zip.ZipInputStream.get32(this.tmpbuf,22));c=java.util.zip.ZipInputStream.get16(this.tmpbuf,28);if(0<c){var b=x(c,0);this.readFully(b,0,c);m.setExtra(b);if(4294967295==m.csize||4294967295==m.size)for(var g=0;g+4<c;){var h=java.util.zip.ZipInputStream.get16(b,g+2);if(1==java.util.zip.ZipInputStream.get16(b,
+g)){g+=4;if(16>h||g+h>c)break;m.size=java.util.zip.ZipInputStream.get64(b,g);m.csize=java.util.zip.ZipInputStream.get64(b,g+8);break}g+=h+4}}return m});d(b,"toStringUTF8",function(a,c){try{return String.instantialize(a,0,c,this.zc)}catch(b){if(t(b,"java.io.UnsupportedEncodingException"))return this.toStringb2(a,c);throw b;}},"~A,~N");d(b,"toStringb2",function(a,c){return String.instantialize(a,0,c)},"~A,~N");d(b,"createZipEntry",function(a){return new java.util.zip.ZipEntry(a)},"~S");d(b,"readEnd",
+function(a){var c=this.inf.getAvailIn();0<c&&(this.$in.unread(this.buf,this.len-c,c),this.eof=!1);8==(this.flag&8)&&(4294967295<this.inf.getTotalOut()||4294967295<this.inf.getTotalIn()?(this.readFully(this.tmpbuf,0,24),c=java.util.zip.ZipInputStream.get32(this.tmpbuf,0),134695760!=c?(a.crc=c,a.csize=java.util.zip.ZipInputStream.get64(this.tmpbuf,4),a.size=java.util.zip.ZipInputStream.get64(this.tmpbuf,12),this.$in.unread(this.tmpbuf,19,4)):(a.crc=java.util.zip.ZipInputStream.get32(this.tmpbuf,4),
+a.csize=java.util.zip.ZipInputStream.get64(this.tmpbuf,8),a.size=java.util.zip.ZipInputStream.get64(this.tmpbuf,16))):(this.readFully(this.tmpbuf,0,16),c=java.util.zip.ZipInputStream.get32(this.tmpbuf,0),134695760!=c?(a.crc=c,a.csize=java.util.zip.ZipInputStream.get32(this.tmpbuf,4),a.size=java.util.zip.ZipInputStream.get32(this.tmpbuf,8),this.$in.unread(this.tmpbuf,11,4)):(a.crc=java.util.zip.ZipInputStream.get32(this.tmpbuf,4),a.csize=java.util.zip.ZipInputStream.get32(this.tmpbuf,8),a.size=java.util.zip.ZipInputStream.get32(this.tmpbuf,
+12))));if(a.size!=this.inf.getTotalOut())throw new java.util.zip.ZipException("invalid entry size (expected "+a.size+" but got "+this.inf.getTotalOut()+" bytes)");if(a.csize!=this.inf.getTotalIn())throw new java.util.zip.ZipException("invalid entry compressed size (expected "+a.csize+" but got "+this.inf.getTotalIn()+" bytes)");if(a.crc!=this.crc.getValue())throw new java.util.zip.ZipException("invalid entry CRC (expected 0x"+Long.toHexString(a.crc)+" but got 0x"+Long.toHexString(this.crc.getValue())+
+")");},"java.util.zip.ZipEntry");d(b,"readFully",function(a,c,b){for(;0<b;){var e=this.$in.read(a,c,b);if(-1==e)throw new java.io.EOFException;c+=e;b-=e}},"~A,~N,~N");b.get16=d(b,"get16",function(a,c){return a[c]&255|(a[c+1]&255)<<8},"~A,~N");b.get32=d(b,"get32",function(a,c){return(java.util.zip.ZipInputStream.get16(a,c)|java.util.zip.ZipInputStream.get16(a,c+2)<<16)&4294967295},"~A,~N");b.get64=d(b,"get64",function(a,c){return java.util.zip.ZipInputStream.get32(a,c)|java.util.zip.ZipInputStream.get32(a,
+c+4)<<32},"~A,~N")});z("java.util.zip");y(["com.jcraft.jzlib.CRC32"],"java.util.zip.CRC32",null,function(){F(java.util.zip,"CRC32",com.jcraft.jzlib.CRC32)});z("java.util.zip");y(["com.jcraft.jzlib.InflaterInputStream"],"java.util.zip.InflaterInputStream",null,function(){var b=A(function(){this.inf=null;B(this,arguments)},java.util.zip,"InflaterInputStream",com.jcraft.jzlib.InflaterInputStream);D(b,function(a,c,b){K(this,java.util.zip.InflaterInputStream,[a,c,b,!0]);this.inf=c},"java.io.InputStream,java.util.zip.Inflater,~N")});
+z("java.util.zip");y(["java.util.zip.InflaterInputStream","$.CRC32"],"java.util.zip.GZIPInputStream",["java.util.zip.CheckedInputStream","$.Inflater"],function(){var b=A(function(){this.crc=null;this.$closed=this.eos=!1;this.tmpbuf=null;B(this,arguments)},java.util.zip,"GZIPInputStream",java.util.zip.InflaterInputStream);L(b,function(){this.crc=new java.util.zip.CRC32;this.tmpbuf=x(128,0)});D(b,function(a,c){K(this,java.util.zip.GZIPInputStream,[a,(new java.util.zip.Inflater).init(0,!0),c]);this.readHeader(a)},
+"java.io.InputStream,~N");d(b,"ensureOpen",function(){if(this.$closed)throw new java.io.IOException("Stream closed");});d(b,"read",function(a,c,b){this.ensureOpen();if(this.eos)return-1;var e=this.readInf(a,c,b);if(-1==e)if(this.readTrailer())this.eos=!0;else return this.read(a,c,b);else this.crc.update(a,c,e);return e},"~A,~N,~N");d(b,"close",function(){this.$closed||(P(this,java.util.zip.GZIPInputStream,"close",[]),this.$closed=this.eos=!0)});d(b,"readHeader",function(a){a=(new java.util.zip.CheckedInputStream(a)).set(this.crc);
+this.crc.reset();if(35615!=this.readUShort(a))throw new java.util.zip.ZipException("Not in GZIP format");if(8!=this.readUByte(a))throw new java.util.zip.ZipException("Unsupported compression method");var c=this.readUByte(a);this.skipBytes(a,6);var b=10;if(4==(c&4)){var e=this.readUShort(a);this.skipBytes(a,e);b+=e+2}if(8==(c&8)){do b++;while(0!=this.readUByte(a))}if(16==(c&16)){do b++;while(0!=this.readUByte(a))}if(2==(c&2)){c=this.crc.getValue()&65535;if(this.readUShort(a)!=c)throw new java.util.zip.ZipException("Corrupt GZIP header");
+b+=2}this.crc.reset();return b},"java.io.InputStream");d(b,"readTrailer",function(){return!0});d(b,"readUShort",function(a){var c=this.readUByte(a);return this.readUByte(a)<<8|c},"java.io.InputStream");d(b,"readUByte",function(a){a=a.readByteAsInt();if(-1==a)throw new java.io.EOFException;if(-1>a||255<a)throw new java.io.IOException(this.$in.getClass().getName()+".read() returned value out of range -1..255: "+a);return a},"java.io.InputStream");d(b,"skipBytes",function(a,c){for(;0<c;){var b=a.read(this.tmpbuf,
+0,c<this.tmpbuf.length?c:this.tmpbuf.length);if(-1==b)throw new java.io.EOFException;c-=b}},"java.io.InputStream,~N")});z("javajs.api");y(["java.util.zip.ZipInputStream","javajs.api.ZInputStream"],"javajs.api.GenericZipInputStream",null,function(){F(javajs.api,"GenericZipInputStream",java.util.zip.ZipInputStream,javajs.api.ZInputStream)});z("JU");y(["javajs.api.GenericZipTools"],"JU.ZipTools","java.io.BufferedInputStream java.util.zip.CRC32 $.GZIPInputStream $.ZipEntry javajs.api.GenericZipInputStream $.Interface JU.BArray $.Lst $.Rdr $.SB".split(" "),
 function(){var b=F(JU,"ZipTools",null,javajs.api.GenericZipTools);k(b,"newZipInputStream",function(a){return JU.ZipTools.newZIS(a)},"java.io.InputStream");b.newZIS=d(b,"newZIS",function(a){return I(a,"java.util.zip.ZipInputStream")?a:I(a,"java.io.BufferedInputStream")?new javajs.api.GenericZipInputStream(a):new javajs.api.GenericZipInputStream(new java.io.BufferedInputStream(a))},"java.io.InputStream");k(b,"getAllZipData",function(){},"java.io.InputStream,~A,~S,~S,~S,java.util.Map");k(b,"getZipFileDirectory",
 function(a,c,b,e){var g,h=null==c||b>=c.length,f=h?".":c[b];if(JU.Rdr.isTar(a))return JU.ZipTools.getTarFileDirectory(a,f,e);if(h)return this.getZipDirectoryAsStringAndClose(a);a=JU.Rdr.getPngZipStream(a,!0);a=JU.ZipTools.newZIS(a);var j;try{var d=f.equals(".");if(d||f.lastIndexOf("/")==f.length-1){for(g=new JU.SB;null!=(j=a.getNextEntry());){var v=j.getName();(d||v.startsWith(f))&&g.append(v).appendC("\n")}var q=g.toString();return e?JU.Rdr.getBIS(q.getBytes()):q}var r=f.indexOf(":asBinaryString");
 (d=0<r)&&(f=f.substring(0,r));for(f=f.$replace("\\","/");null!=(j=a.getNextEntry())&&!f.equals(j.getName()););var p=null==j?null:JU.Rdr.getLimitedStreamBytes(a,j.getSize());a.close();if(null==p)return"";if(JU.Rdr.isZipB(p)||JU.Rdr.isPngZipB(p))return this.getZipFileDirectory(JU.Rdr.getBIS(p),c,++b,e);if(e)return JU.Rdr.getBIS(p);if(d){g=new JU.SB;for(c=0;c<p.length;c++)g.append(Integer.toHexString(p[c]&255)).appendC(" ");return g.toString()}JU.Rdr.isGzipB(p)&&(p=JU.Rdr.getLimitedStreamBytes(this.getUnGzippedInputStream(p),
